@@ -32,7 +32,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.0.10"
+__version__ = "1.0.11"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Ducky.git"
 
 commands = {
@@ -132,7 +132,7 @@ class Ducky:
 
         with open(filename, "r") as duckyscript:
             for line in duckyscript:
-                self.lines.append(line[:-1])
+                self.lines.append(line[:-1].rstrip("\r"))
 
     def loop(  # pylint: disable=too-many-return-statements
         self, line: Optional[str] = None
